==> haskell-pretty-hex-1.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pretty-hex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pretty-hex
version:              1.1
visibility:           public
id:                   pretty-hex-1.1-LeIcJE8JSPz4oaRdpqV604
key:                  pretty-hex-1.1-LeIcJE8JSPz4oaRdpqV604
license:              BSD-3-Clause
maintainer:           Eric Mertens <emertens@galois.com>
synopsis:             A library for hex dumps of ByteStrings
description:
    This library generates pretty hex dumps of ByteStrings in the
    style of other common *nix hex dump tools.

category:             Data
abi:                  64a2e2dac365e93342a29d179cc4b52a
exposed:              True
exposed-modules:      Hexdump
import-dirs:          /usr/lib/ghc-8.8.3/site-local/pretty-hex-1.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/pretty-hex-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/pretty-hex-1.1
hs-libraries:         HSpretty-hex-1.1-LeIcJE8JSPz4oaRdpqV604
depends:              base-4.13.0.0 bytestring-0.10.10.0
haddock-interfaces:   /usr/share/doc/haskell-pretty-hex/html/pretty-hex.haddock
haddock-html:         /usr/share/doc/haskell-pretty-hex/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pretty-hex-1.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pretty-hex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pretty-hex
version:              1.1
visibility:           public
id:                   pretty-hex-1.1-GrJ47rTLcMl5IENzUWyyN7
key:                  pretty-hex-1.1-GrJ47rTLcMl5IENzUWyyN7
license:              BSD-3-Clause
maintainer:           Eric Mertens <emertens@galois.com>
synopsis:             A library for hex dumps of ByteStrings
description:
    This library generates pretty hex dumps of ByteStrings in the
    style of other common *nix hex dump tools.

category:             Data
abi:                  5da3ce3122503c6d79ef2c48264fd643
exposed:              True
exposed-modules:      Hexdump
import-dirs:          /usr/lib/ghc-8.10.1/site-local/pretty-hex-1.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/pretty-hex-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/pretty-hex-1.1
hs-libraries:         HSpretty-hex-1.1-GrJ47rTLcMl5IENzUWyyN7
depends:              base-4.14.0.0 bytestring-0.10.10.0
haddock-interfaces:   /usr/share/doc/haskell-pretty-hex/html/pretty-hex.haddock
haddock-html:         /usr/share/doc/haskell-pretty-hex/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
